[−][src]Struct dbl::types::Listing
Search result returned by Client::search.
Fields
results: Vec<Bot>limit: u64offset: u64count: u64total: u64Trait Implementations
impl IntoIterator for Listing[src]
type Item = Bot
The type of the elements being iterated over.
type IntoIter = IntoIter<Bot>
Which kind of iterator are we turning this into?
fn into_iter(self) -> Self::IntoIter[src]
impl<'a> IntoIterator for &'a Listing[src]
type Item = &'a Bot
The type of the elements being iterated over.
type IntoIter = Iter<'a, Bot>
Which kind of iterator are we turning this into?
fn into_iter(self) -> Self::IntoIter[src]
impl Debug for Listing[src]
impl Index<usize> for Listing[src]
type Output = Bot
The returned type after indexing.
fn index(&self, index: usize) -> &Self::Output[src]
impl<'de> Deserialize<'de> for Listing[src]
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error> where
__D: Deserializer<'de>, [src]
__D: Deserializer<'de>,